==> substance_4.3.11.orig.tar.gz: substance-4.3.11.orig/src/org/jvnet/substance/skin/SkinInfo.java <==
/*
 * Copyright (c) 2005-2008 Substance Kirill Grouchnikov. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 
 *  o Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer. 
 *     
 *  o Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution. 
 *     
 *  o Neither the name of Substance Kirill Grouchnikov nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission. 
 *     
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */
package org.jvnet.substance.skin;

import org.jvnet.substance.utils.AbstractTraitInfo;

/**
 * Information on a single skin. This class is part of officially supported API.
 * 
 * @author Kirill Grouchnikov
 */
public class SkinInfo extends AbstractTraitInfo {
	/**
	 * Simple constructor.
	 * 
	 * @param skinDisplayName
	 *            Display name of <code>this</code> skin.
	 * @param skinClassName
	 *            Class name of <code>this</code> skin.
	 */
	public SkinInfo(String skinDisplayName, String skinClassName) {
		super(skinDisplayName, skinClassName);
	}

	/**
	 * Returns the class name of <code>this</code> skin.
	 * 
	 * @return The class name of <code>this</code> skin.
	 * @deprecated Use {@link #getClassName()} instead.
	 */
	public String getSkinClassName() {
		return this.getClassName();
	}

	/**
	 * Returns the display name of <code>this</code> skin.
	 * 
	 * @return The display name of <code>this</code> skin.
	 * @deprecated Use {@link #getDisplayName()} instead.
	 */
	public String getSkinDisplayName() {
		return this.getDisplayName();
	}
}

==> substance_5.0.orig.tar.gz: substance-5.0.orig/src/org/jvnet/substance/skin/SkinInfo.java <==
/*
 * Copyright (c) 2005-2008 Substance Kirill Grouchnikov. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 
 *  o Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer. 
 *     
 *  o Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution. 
 *     
 *  o Neither the name of Substance Kirill Grouchnikov nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission. 
 *     
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */
package org.jvnet.substance.skin;

import org.jvnet.substance.utils.TraitInfoImpl;

/**
 * Information on a single skin. This class is part of officially supported API.
 * 
 * @author Kirill Grouchnikov
 */
public class SkinInfo extends TraitInfoImpl {
	/**
	 * Simple constructor.
	 * 
	 * @param skinDisplayName
	 *            Display name of <code>this</code> skin.
	 * @param skinClassName
	 *            Class name of <code>this</code> skin.
	 */
	public SkinInfo(String skinDisplayName, String skinClassName) {
		super(skinDisplayName, skinClassName);
	}
}
